# -*- coding: utf-8 -*-

"""
MEDIA:
    Proceso, CDMX

USAGE:
    $ cd proceso/
    ------------------------------------------------------------------------------------------------------------
    ## Get all the news from the most current to the oldest for one year. It's necessary to use the parse_date_files.py
    file for the news contained in noticias.json being splitted into files by date. ##
    
    $ scrapy crawl noticias --nolog -s filename=2018.json -a year=2018
"""

import scrapy, re, requests
from proceso.items import NoticiasItem
from datetime import date, datetime

TAG_RE = re.compile(r'<[^>]+>')
def remove_tags(text):
    return TAG_RE.sub('', text)

DATE  = re.compile(r'\$\(\"\#iny-date\"\)\.html\(\'(.*?)\'\);')
TITLE = re.compile(r'\$\(\"\#iny-title\"\)\.html\(\'(.*?)\'\);')
TOPIC = re.compile(r'\$\(\"\#iny-category\"\)\.html\(\'(.*?)\'\);')
CONTENT = re.compile(r'content_lines \+= \'(.*?)\'')


class QuotesSpider(scrapy.Spider):
    """
    Basic Scrapy Spider class
    """
    name = "noticias"


    def start_requests(self):
        year  = getattr(self, "year", None)
        month = getattr(self, "month", None)
        day   = getattr(self, "day", None)

        self.stop_date = date(2018, 9, 15)

        """
            Iniciar sesion en el navegador, buscar la noticia deseada y en la seccion Network de las herramientas de desarrolladores buscar la archivo
            wp-login-6a28500e1f.js.php?page_id=420235, click derecho y copiar como curl.
            Parsear el curl command a python requests.
            Pegar en este archivo las cookies y los headers, en self.cookies y self.headers respectivamente.
        """

        self.logged_in_link = "https://hemeroteca.proceso.com.mx/wp-login-6a28500e1f.js.php"

        self.cookies = {
            '__auc': '716d2c791661564eaf19d7da29c',
            '_io_un': '',
            '__gads': 'ID=f530a1448b07ba8d:T=1537957532:S=ALNI_MbwbTDehpjreM-pfG17_0dfanqayQ',
            '__cfduid': 'df2897ebe2d430cacad2c4cbe30238d6e1537957552',
            '_ga': 'GA1.3.770661327.1537957227',
            '_gid': 'GA1.3.56098531.1545061125',
            'CloudFront-Key-Pair-Id': 'APKAJIUNCAFIFZIBZZNQ',
            'CloudFront-Policy': 'eyJTdGF0ZW1lbnQiOlt7IlJlc291cmNlIjoiaHR0cCo6Ly9yZXZpc3RhLnByb2Nlc28uY29tLm14LzIxNzMvKiIsIkNvbmRpdGlvbiI6eyJEYXRlTGVzc1RoYW4iOnsiSXBBZGRyZXNzIjp7IkFXUzpTb3VyY2VJcCI6IjE3Ny4yMzcuMTQ0Ljk5LzMyIn0sIkFXUzpFcG9jaFRpbWUiOjE1NDUyMjk1MTV9fX1dfQ__',
            'CloudFront-Signature': 'jsBurtdKb8cjh33rHDJwH94E3b4aphF3sXbAHPIEAZKcY7VYeE32AxLiCZ5WuGJyTr5h44f67FjRB3chUCShT32XpQ2cEVYneft3i7nRujMo3ElVcxR6GJyjMAfb-2NUMi7Fqi~mQEvD2GS4Dap9utqunObljVf6f0nB2Yw1PEBvhT0kk5VoUDXuSHbS70xqW6TdXR6E8Aatao49Oejx-q20Ke7~jY1L4OKCuoW8ValTXc~c6Jjv13Tv9M3z18x11LlG0Nkxl4l4h9n07wYq~nVkGoi~8ieEiFSbl7Uoo9f37E4FWOfknYFiV8tPMvi7ltC036f6Lah7HevJQvVdXg__',
            'cf_clearance': 'd76b9e56d6517fdb2e9083d63e69eaedef66bc3f-1545150003-1800-150',
            '__asc': 'fab2e041167c2184ed47905fbc7',
            '_gat_gtag_UA_24909634_2': '1',
            '_gat_Insticator_Embed_v4': '1',
            'wordpress_test_cookie': 'WP+Cookie+check',
            'hemeroteca': 'carlos_silvaforne%40yahoo.com.mx%7C1545322845%7CE2Tz5fLMVkSMLh2FNEvKvIsiA2xGncuA4sJdgvipCdB%7Cc29cb11d05da5f7be07ae0cbfee865700e6cd3b0c21dad2e40674668e2d6a9db',
        }

        self.headers = {
            'DNT': '1',
            'Accept-Encoding': 'gzip, deflate',
            'Accept-Language': 'es-419,es;q=0.9,en;q=0.8',
            'User-Agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/70.0.3538.77 Safari/537.36',
            'Accept': '*/*',
            'Referer': 'http://hemeroteca.proceso.com.mx/?page_id=420235',
            'Connection': 'keep-alive',
        }

        # self.baseURL = "https://hemeroteca.proceso.com.mx/"
        self.baseURL = "https://hemeroteca.proceso.com.mx/?page_id=111058&edicion=mexico&page={0}".format(year)
        
        yield scrapy.Request(url=self.baseURL, callback=self.parse_magazine)



    def parse_magazine(self, response):
        for link in response.css('div.catalogo-portadas').css('div.catpor-post-thumb > a::attr(href)').extract():
            yield scrapy.Request(url=link, callback=self.parse_news)
        # url_1 = "https://hemeroteca.proceso.com.mx/?page_id=419579"
        # yield scrapy.Request(url=url_1, callback=self.parse_news)



    def parse_news(self, response):
        for news_link in response.css('div.hfeed').css('h2.entry-title > a::attr(href)').extract():
        #     print news_link
        # news_link = response.css('div.hfeed').css('h2.entry-title > a::attr(href)').extract_first()
        # news_link = "https://hemeroteca.proceso.com.mx/?page_id=278958&a51dc26366d99bb5fa29cea4747565fec=419589"

            news_id = news_link[news_link.rfind("=")+1:]

            self.headers['Referer'] = news_link

            params = (
                ('page_id', '278958'),
                ('a51dc26366d99bb5fa29cea4747565fec', news_id),
            )

            response = requests.get(self.logged_in_link, headers=self.headers,
                                    params=params, cookies=self.cookies)

            # print "\n"
            # print response.text + "\n\n"
            response_text = response.text.replace("var content_lines = '';", '')
            response_text = response_text.replace('content_lines += \'<p class=\\"p1\\">\';', '')
            # print response_text

            news_date = DATE.findall(response_text)
            news_date = news_date[0]
            news_date = news_date.split(' ')
            news_d = datetime.strptime(news_date[0], '%Y-%m-%d').date()

            if news_d <= self.stop_date:
                item = NoticiasItem()
                news_date = "T".join(news_date)
                # print news_date

                title = TITLE.findall(response_text)
                news_title = title[0].strip()
                # print news_title

                topic = TOPIC.findall(response_text)
                news_topic = topic[0].strip()
                # print news_topic

                text = ''
                matches = CONTENT.findall(response_text)
                for match in matches:
                    adition = remove_tags(match)
                    if adition != '':
                        text += adition + "\n"
                news_text = text.strip()
                # print news_text

                print "date: {0}".format(news_date)   
                
                item['date']  = news_date
                item['title'] = news_title
                item['topic'] = news_topic
                item['text']  = news_text
                item['url']   = news_link

                yield item
